import { EventEmitter, OnInit, ElementRef, Renderer } from '@angular/core';
import { AcTextTreeNode, AcTreeNode } from './models';
/**
 * The treenode class represents a single treenode for the treeview. Actually, this renders the real UI.
 *
 * The component needs this input value:
 *
 * * @Input() node: AcTextTreeNode;
 *
 * The several options are set through the AcTreeNodeOptions object that is being held by the
 * AcTextTreeNode class. This includes colors, icons, and other styles.
 *
 * The component can fire these events:
 *
 * * @Output() nodeClick: EventEmitter<AcTreeNode>;
 * * @Output() checkChanged: EventEmitter<AcTreeNode>;
 * * @Output() selectedChanged: EventEmitter<AcTreeNode>;
 * * @Output() collapseChanged: EventEmitter<AcTreeNode>;
 *
 */
export declare class AcTreeViewNodeComponent implements OnInit {
    private el;
    private renderer;
    private static pfxIcon;
    private static opnIcon;
    private static clsIcon;
    /**
     * The object that controls the node's appearance.
     */
    node: AcTextTreeNode;
    /**
     * Fired on click and hence fired even if any of the other parts are being fired.
     */
    nodeClick: EventEmitter<AcTreeNode>;
    /**
     * Fired if a checkable field is being clicked.
     */
    checkChanged: EventEmitter<AcTreeNode>;
    /**
     * Fired if a selectable field is being clicked.
     */
    selectedChanged: EventEmitter<AcTreeNode>;
    /**
     * Fired if a node collapses or expands.
     */
    collapseChanged: EventEmitter<AcTreeNode>;
    href: string;
    collapseClasses: Array<string>;
    iconClasses: Array<string>;
    foreColor: string;
    backColor: string;
    isExpanded: boolean;
    constructor(el: ElementRef, renderer: Renderer);
    ngOnInit(): void;
    onNodeClick(node: AcTreeNode): void;
    onCheckChanged(node: AcTreeNode): void;
    onSelectedChanged(node: AcTreeNode): void;
    onCollapseChanged(node: AcTreeNode): void;
    handleCheckChange(): void;
    handleClick($event: any): void;
    handleCollapse(): void;
    private preSelectState;
    handlePreSelection(state: boolean): void;
    handleSelection($event: any): void;
}
